/// Represents a configuration for a given api key.
///
/// For making any request from film_gyan an API key has to
/// be given to the SDK.
///
/// Go to https://www.themoviedb.org/settings/api to create an API key.
///
/// Few optional parameters are also needed while making the api call.
///
/// [language] : The language in which the response has to be returned.
/// Default value is en-US. If want to use en-US no need to pass that value.
///
/// [region] : The region for which the response is needed. Not all apis support
/// this but specific apis uses this to give data based on region.
/// If the value is not specified then the default value will be used.
class Credentials {
  Credentials({
    required this.apiKey,
    this.language = 'en-US',
    this.region = 'US',
  });

  /// API key for https://www.themoviedb.org/
  String apiKey;

  /// Language for the response
  String language;

  /// Get response based on region
  String region;
}
