// coverage:ignore-file
import 'dart:convert';

import 'package:film_gyaan/core.dart';

/// @nodoc
class TvDetails extends Result {
  TvDetails({
    required this.backdropPath,
    required this.createdBy,
    required this.episodeRunTime,
    required this.firstAirDate,
    required this.genres,
    required this.homepage,
    required this.id,
    required this.inProduction,
    required this.languages,
    required this.lastAirDate,
    required this.lastEpisodeToAir,
    required this.name,
    required this.nextEpisodeToAir,
    required this.networks,
    required this.numberOfEpisodes,
    required this.numberOfSeasons,
    required this.originCountry,
    required this.originalLanguage,
    required this.originalName,
    required this.overview,
    required this.popularity,
    required this.posterPath,
    required this.productionCompanies,
    required this.productionCountries,
    required this.seasons,
    required this.spokenLanguages,
    required this.status,
    required this.tagline,
    required this.type,
    required this.voteAverage,
    required this.voteCount,
    required this.aggregateCredits,
    required this.alternativeTitles,
    required this.contentRatings,
    required this.credits,
    required this.episodeGroups,
    required this.externalIds,
    required this.images,
    required this.keywords,
    required this.recommendations,
    required this.reviews,
    required this.screenedTheatrically,
    required this.similar,
    required this.translations,
    required this.videos,
  });

  factory TvDetails.fromJson(String str) => TvDetails.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory TvDetails.fromMap(Map<String, dynamic> json) => TvDetails(
        backdropPath: json['backdrop_path'] as String? ?? '',
        createdBy: List<CreatedBy>.from(
          (json['created_by'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => CreatedBy.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
        episodeRunTime: List<int>.from(
          (json['episode_run_time'] as List<dynamic>? ?? <dynamic>[])
              .map<dynamic>(
            (dynamic x) => x as int,
          ),
        ),
        firstAirDate: DateTime.tryParse(
          json['first_air_date'] as String? ?? '',
        ),
        genres: List<Genre>.from(
          (json['genres'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => Genre.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
        homepage: json['homepage'] as String? ?? '',
        id: json['id'] as int? ?? 0,
        inProduction: json['in_production'] as bool? ?? false,
        languages: List<String>.from(
          (json['languages'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => x as String,
          ),
        ),
        lastAirDate: DateTime.tryParse(
          json['last_air_date'] as String? ?? '',
        ),
        lastEpisodeToAir: TEpisodeToAir.fromMap(
          json['last_episode_to_air'] as Map<String, dynamic>? ??
              <String, dynamic>{},
        ),
        name: json['name'] as String? ?? '',
        nextEpisodeToAir: TEpisodeToAir.fromMap(
          json['next_episode_to_air'] as Map<String, dynamic>? ??
              <String, dynamic>{},
        ),
        networks: List<Network>.from(
          (json['networks'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => Network.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
        numberOfEpisodes: json['number_of_episodes'] as int? ?? 0,
        numberOfSeasons: json['number_of_seasons'] as int? ?? 0,
        originCountry: List<String>.from(
          (json['origin_country'] as List<dynamic>? ?? <dynamic>[])
              .map<dynamic>(
            (dynamic x) => x as String,
          ),
        ),
        originalLanguage: json['original_language'] as String? ?? '',
        originalName: json['original_name'] as String? ?? '',
        overview: json['overview'] as String? ?? '',
        popularity: json['popularity'] as num? ?? 0,
        posterPath: json['poster_path'] as String? ?? '',
        productionCompanies: List<Network>.from(
          (json['production_companies'] as List<dynamic>? ?? <dynamic>[])
              .map<dynamic>(
            (dynamic x) => Network.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
        productionCountries: List<ProductionCountry>.from(
          (json['production_countries'] as List<dynamic>? ?? <dynamic>[])
              .map<dynamic>(
            (dynamic x) => ProductionCountry.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
        seasons: List<Season>.from(
          (json['seasons'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => Season.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
        spokenLanguages: List<SpokenLanguage>.from(
          (json['spoken_languages'] as List<dynamic>? ?? <dynamic>[])
              .map<dynamic>(
            (dynamic x) => SpokenLanguage.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
        status: json['status'] as String? ?? '',
        tagline: json['tagline'] as String? ?? '',
        type: json['type'] as String? ?? '',
        voteAverage: json['vote_average'] as num? ?? 0,
        voteCount: json['vote_count'] as int? ?? 0,
        aggregateCredits: Credits.fromMap(
          json['aggregate_credits'] as Map<String, dynamic>? ??
              <String, dynamic>{},
        ),
        alternativeTitles: AlternativeTitles.fromMap(
          json['alternative_titles'] as Map<String, dynamic>? ??
              <String, dynamic>{},
        ),
        contentRatings: ContentRatings.fromMap(
          json['content_ratings'] as Map<String, dynamic>? ??
              <String, dynamic>{},
        ),
        credits: Credits.fromMap(
          json['credits'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
        episodeGroups: EpisodeGroups.fromMap(
          json['episode_groups'] as Map<String, dynamic>? ??
              <String, dynamic>{},
        ),
        externalIds: ExternalIds.fromMap(
          json['external_ids'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
        images: Images.fromMap(
          json['images'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
        keywords: Keywords.fromMap(
          json['keywords'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
        recommendations: TvRecommendations.fromMap(
          json['recommendations'] as Map<String, dynamic>? ??
              <String, dynamic>{},
        ),
        reviews: ReviewsList.fromMap(
          json['reviews'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
        screenedTheatrically: AlternativeTitles.fromMap(
          json['screened_theatrically'] as Map<String, dynamic>? ??
              <String, dynamic>{},
        ),
        similar: TvRecommendations.fromMap(
          json['similar'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
        translations: Translations.fromMap(
          json['translations'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
        videos: Videos.fromMap(
          json['videos'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
      );

  String backdropPath;
  List<CreatedBy> createdBy;
  List<int> episodeRunTime;
  DateTime? firstAirDate;
  List<Genre> genres;
  String homepage;
  int id;
  bool inProduction;
  List<String> languages;
  DateTime? lastAirDate;
  TEpisodeToAir lastEpisodeToAir;
  String name;
  TEpisodeToAir nextEpisodeToAir;
  List<Network> networks;
  int numberOfEpisodes;
  int numberOfSeasons;
  List<String> originCountry;
  String originalLanguage;
  String originalName;
  String overview;
  num popularity;
  String posterPath;
  List<Network> productionCompanies;
  List<ProductionCountry> productionCountries;
  List<Season> seasons;
  List<SpokenLanguage> spokenLanguages;
  String status;
  String tagline;
  String type;
  num voteAverage;
  int voteCount;
  Credits aggregateCredits;
  AlternativeTitles alternativeTitles;
  ContentRatings contentRatings;
  Credits credits;
  EpisodeGroups episodeGroups;
  ExternalIds externalIds;
  Images images;
  Keywords keywords;
  TvRecommendations recommendations;
  ReviewsList reviews;
  AlternativeTitles screenedTheatrically;
  TvRecommendations similar;
  Translations translations;
  Videos videos;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'backdrop_path': backdropPath,
        'created_by': List<dynamic>.from(
          createdBy.map<dynamic>(
            (x) => x.toMap(),
          ),
        ),
        'episode_run_time': List<dynamic>.from(
          episodeRunTime.map<dynamic>(
            (x) => x,
          ),
        ),
        'first_air_date': firstAirDate == null
            ? null
            : "${firstAirDate!.year.toString().padLeft(4, '0')}-${firstAirDate!.month.toString().padLeft(2, '0')}-${firstAirDate!.day.toString().padLeft(2, '0')}",
        'genres': List<dynamic>.from(
          genres.map<dynamic>(
            (x) => x.toMap(),
          ),
        ),
        'homepage': homepage,
        'id': id,
        'in_production': inProduction,
        'languages': List<dynamic>.from(
          languages.map<dynamic>(
            (x) => x,
          ),
        ),
        'last_air_date': lastAirDate == null
            ? null
            : "${lastAirDate!.year.toString().padLeft(4, '0')}-${lastAirDate!.month.toString().padLeft(2, '0')}-${lastAirDate!.day.toString().padLeft(2, '0')}",
        'last_episode_to_air': lastEpisodeToAir.toMap(),
        'name': name,
        'next_episode_to_air': nextEpisodeToAir.toMap(),
        'networks': List<dynamic>.from(
          networks.map<dynamic>(
            (x) => x.toMap(),
          ),
        ),
        'number_of_episodes': numberOfEpisodes,
        'number_of_seasons': numberOfSeasons,
        'origin_country': List<dynamic>.from(
          originCountry.map<dynamic>(
            (x) => x,
          ),
        ),
        'original_language': originalLanguage,
        'original_name': originalName,
        'overview': overview,
        'popularity': popularity,
        'poster_path': posterPath,
        'production_companies': List<dynamic>.from(
          productionCompanies.map<dynamic>(
            (x) => x.toMap(),
          ),
        ),
        'production_countries': List<dynamic>.from(
          productionCountries.map<dynamic>(
            (x) => x.toMap(),
          ),
        ),
        'seasons': List<dynamic>.from(
          seasons.map<dynamic>(
            (x) => x.toMap(),
          ),
        ),
        'spoken_languages': List<dynamic>.from(
          spokenLanguages.map<dynamic>(
            (x) => x.toMap(),
          ),
        ),
        'status': status,
        'tagline': tagline,
        'type': type,
        'vote_average': voteAverage,
        'vote_count': voteCount,
        'aggregate_credits': aggregateCredits.toMap(),
        'alternative_titles': alternativeTitles.toMap(),
        'content_ratings': contentRatings.toMap(),
        'credits': credits.toMap(),
        'episode_groups': episodeGroups.toMap(),
        'external_ids': externalIds.toMap(),
        'images': images.toMap(),
        'keywords': keywords.toMap(),
        'recommendations': recommendations.toMap(),
        'reviews': reviews.toMap(),
        'screened_theatrically': screenedTheatrically.toMap(),
        'similar': similar.toMap(),
        'translations': translations.toMap(),
        'videos': videos.toMap(),
      };
}

class Job {
  Job({
    required this.creditId,
    required this.job,
    required this.episodeCount,
  });

  factory Job.fromJson(String str) => Job.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory Job.fromMap(Map<String, dynamic> json) => Job(
        creditId: json['credit_id'] as String? ?? '',
        job: json['job'] as String? ?? '',
        episodeCount: json['episode_count'] as int? ?? 0,
      );

  String creditId;
  String job;
  int episodeCount;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'credit_id': creditId,
        'job': job,
        'episode_count': episodeCount,
      };
}

class CreatedBy {
  CreatedBy({
    required this.id,
    required this.creditId,
    required this.name,
    required this.gender,
    required this.profilePath,
  });

  factory CreatedBy.fromJson(String str) => CreatedBy.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory CreatedBy.fromMap(Map<String, dynamic> json) => CreatedBy(
        id: json['id'] as int? ?? 0,
        creditId: json['credit_id'] as String? ?? '',
        name: json['name'] as String? ?? '',
        gender: json['gender'] as int? ?? 0,
        profilePath: json['profile_path'] as String? ?? '',
      );

  int id;
  String creditId;
  String name;
  int gender;
  String profilePath;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'id': id,
        'credit_id': creditId,
        'name': name,
        'gender': gender,
        'profile_path': profilePath,
      };
}

class Role {
  Role({
    required this.creditId,
    required this.character,
    required this.episodeCount,
  });

  factory Role.fromJson(String str) => Role.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory Role.fromMap(Map<String, dynamic> json) => Role(
        creditId: json['credit_id'] as String? ?? '',
        character: json['character'] as String? ?? '',
        episodeCount: json['episode_count'] as int? ?? 0,
      );

  String creditId;
  String character;
  int episodeCount;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'credit_id': creditId,
        'character': character,
        'episode_count': episodeCount,
      };
}

class TEpisodeToAir {
  TEpisodeToAir({
    required this.airDate,
    required this.episodeNumber,
    required this.id,
    required this.name,
    required this.overview,
    required this.productionCode,
    required this.seasonNumber,
    required this.stillPath,
    required this.voteAverage,
    required this.voteCount,
  });

  factory TEpisodeToAir.fromJson(String str) => TEpisodeToAir.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory TEpisodeToAir.fromMap(Map<String, dynamic> json) => TEpisodeToAir(
        airDate: DateTime.tryParse(json['air_date'] as String? ?? ''),
        episodeNumber: json['episode_number'] as int? ?? 0,
        id: json['id'] as int? ?? 0,
        name: json['name'] as String? ?? '',
        overview: json['overview'] as String? ?? '',
        productionCode: json['production_code'] as String? ?? '',
        seasonNumber: json['season_number'] as int? ?? 0,
        stillPath: json['still_path'] as String? ?? '',
        voteAverage: json['vote_average'] as num? ?? 0,
        voteCount: json['vote_count'] as int? ?? 0,
      );

  DateTime? airDate;
  int episodeNumber;
  int id;
  String name;
  String overview;
  String productionCode;
  int seasonNumber;
  String stillPath;
  num voteAverage;
  int voteCount;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'air_date': airDate == null
            ? null
            : "${airDate!.year.toString().padLeft(4, '0')}-${airDate!.month.toString().padLeft(2, '0')}-${airDate!.day.toString().padLeft(2, '0')}",
        'episode_number': episodeNumber,
        'id': id,
        'name': name,
        'overview': overview,
        'production_code': productionCode,
        'season_number': seasonNumber,
        'still_path': stillPath,
        'vote_average': voteAverage,
        'vote_count': voteCount,
      };
}

class Season {
  Season({
    required this.airDate,
    required this.episodeCount,
    required this.id,
    required this.name,
    required this.overview,
    required this.posterPath,
    required this.seasonNumber,
  });

  factory Season.fromJson(String str) => Season.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory Season.fromMap(Map<String, dynamic> json) => Season(
        airDate: DateTime.tryParse(
          json['air_date'] as String? ?? '',
        ),
        episodeCount: json['episode_count'] as int? ?? 0,
        id: json['id'] as int? ?? 0,
        name: json['name'] as String? ?? '',
        overview: json['overview'] as String? ?? '',
        posterPath: json['poster_path'] as String? ?? '',
        seasonNumber: json['season_number'] as int? ?? 0,
      );

  DateTime? airDate;
  int episodeCount;
  int id;
  String name;
  String overview;
  String posterPath;
  int seasonNumber;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'air_date': airDate == null
            ? null
            : "${airDate!.year.toString().padLeft(4, '0')}-${airDate!.month.toString().padLeft(2, '0')}-${airDate!.day.toString().padLeft(2, '0')}",
        'episode_count': episodeCount,
        'id': id,
        'name': name,
        'overview': overview,
        'poster_path': posterPath,
        'season_number': seasonNumber,
      };
}

class TvData {
  TvData({
    required this.name,
    required this.overview,
    required this.homepage,
    required this.tagline,
  });

  factory TvData.fromJson(String str) => TvData.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory TvData.fromMap(Map<String, dynamic> json) => TvData(
        name: json['name'] as String? ?? '',
        overview: json['overview'] as String? ?? '',
        homepage: json['homepage'] as String? ?? '',
        tagline: json['tagline'] as String? ?? '',
      );

  String name;
  String overview;
  String homepage;
  String tagline;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'name': name,
        'overview': overview,
        'homepage': homepage,
        'tagline': tagline,
      };
}
