// coverage:ignore-file
import 'dart:convert';

import 'package:film_gyaan/core.dart';

/// @nodoc
class TvRecommendations extends Result {
  TvRecommendations({
    required this.page,
    required this.results,
    required this.totalPages,
    required this.totalResults,
  });

  factory TvRecommendations.fromJson(String str) => TvRecommendations.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory TvRecommendations.fromMap(Map<String, dynamic> json) =>
      TvRecommendations(
        page: json['page'] as int? ?? 0,
        results: List<TvRecommendationsResult>.from(
          (json['results'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => TvRecommendationsResult.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
        totalPages: json['total_pages'] as int? ?? 0,
        totalResults: json['total_results'] as int? ?? 0,
      );

  int page;
  List<TvRecommendationsResult> results;
  int totalPages;
  int totalResults;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'page': page,
        'results': List<dynamic>.from(results.map<dynamic>((x) => x.toMap())),
        'total_pages': totalPages,
        'total_results': totalResults,
      };
}

class TvRecommendationsResult {
  TvRecommendationsResult({
    required this.adult,
    required this.backdropPath,
    required this.genreIds,
    required this.id,
    required this.mediaType,
    required this.name,
    required this.originCountry,
    required this.originalLanguage,
    required this.originalName,
    required this.overview,
    required this.popularity,
    required this.posterPath,
    required this.firstAirDate,
    required this.voteAverage,
    required this.voteCount,
  });

  factory TvRecommendationsResult.fromJson(String str) =>
      TvRecommendationsResult.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory TvRecommendationsResult.fromMap(Map<String, dynamic> json) =>
      TvRecommendationsResult(
        adult: json['adult'] as bool? ?? false,
        backdropPath: json['backdrop_path'] as String? ?? '',
        genreIds: List<int>.from(
          (json['genre_ids'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => x as String,
          ),
        ),
        id: json['id'] as int? ?? 0,
        mediaType: json['media_type'] as String? ?? '',
        name: json['name'] as String? ?? '',
        originCountry: List<String>.from(
          (json['origin_country'] as List<dynamic>? ?? <dynamic>[])
              .map<dynamic>(
            (dynamic x) => x as String,
          ),
        ),
        originalLanguage: json['original_language'] as String? ?? '',
        originalName: json['original_name'] as String? ?? '',
        overview: json['overview'] as String? ?? '',
        popularity: json['popularity'] as num? ?? 0,
        posterPath: json['poster_path'] as String? ?? '',
        firstAirDate: DateTime.tryParse(
          json['first_air_date'] as String? ?? '',
        ),
        voteAverage: json['vote_average'] as num? ?? 0,
        voteCount: json['vote_count'] as int? ?? 0,
      );

  bool adult;
  String backdropPath;
  List<int> genreIds;
  int id;
  String mediaType;
  String name;
  List<String> originCountry;
  String originalLanguage;
  String originalName;
  String overview;
  num popularity;
  String posterPath;
  DateTime? firstAirDate;
  num voteAverage;
  int voteCount;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'adult': adult,
        'backdrop_path': backdropPath,
        'genre_ids': List<dynamic>.from(
          genreIds.map<dynamic>(
            (x) => x,
          ),
        ),
        'id': id,
        'media_type': mediaType,
        'name': name,
        'origin_country': List<dynamic>.from(
          originCountry.map<dynamic>(
            (x) => x,
          ),
        ),
        'original_language': originalLanguage,
        'original_name': originalName,
        'overview': overview,
        'popularity': popularity,
        'poster_path': posterPath,
        'first_air_date': firstAirDate == null
            ? null
            : "${firstAirDate!.year.toString().padLeft(4, '0')}-${firstAirDate!.month.toString().padLeft(2, '0')}-${firstAirDate!.day.toString().padLeft(2, '0')}",
        'vote_average': voteAverage,
        'vote_count': voteCount,
      };
}
