// coverage:ignore-file
import 'package:film_gyaan/core.dart';

/// A parameter class which will be used to make the initial request for
/// getting the tv aggregate credits.
class TvAggregateCreditsParams extends Parameters {
  TvAggregateCreditsParams({
    required this.tvId,
  });

  int tvId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/$tvId/aggregate_credits',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv airing today.
class TvAiringTodayParams extends Parameters {
  TvAiringTodayParams({
    this.page = 1,
  });

  int page;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/airing_today',
          queryParameters: <String, dynamic>{
            'page': page.toString(),
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv alternative title.
class TvAlternativeTitlesParams extends Parameters {
  TvAlternativeTitlesParams({
    required this.tvId,
  });

  int tvId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/$tvId/alternative_titles',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv content ratings.
class TvContentRatingsParams extends Parameters {
  TvContentRatingsParams({
    required this.tvId,
  });

  int tvId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/$tvId/content_ratings',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv credits.
class TvCreditsParams extends Parameters {
  TvCreditsParams({
    required this.tvId,
  });

  int tvId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/$tvId/credits',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv details.
class TvDetailsParams extends Parameters {
  TvDetailsParams({
    required this.tvId,
  });

  int tvId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/$tvId',
          queryParameters: <String, dynamic>{
            'append_to_response':
                'account_states,aggregate_credits,alternative_titles,content_ratings,credits,episode_groups,external_ids,images,keywords,recommendations,reviews,screened_theatrically,similar,translations,videos',
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv episode groups.
class TvEpisodeGroupsParams extends Parameters {
  TvEpisodeGroupsParams({
    required this.tvId,
  });

  int tvId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/$tvId/episode_groups',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv external ids.
class TvExternalIdsParams extends Parameters {
  TvExternalIdsParams({
    required this.tvId,
  });

  int tvId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/$tvId/external_ids',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv images.
class TvImagesParams extends Parameters {
  TvImagesParams({
    required this.tvId,
  });

  int tvId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/$tvId/images',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv keywords.
class TvKeywordsParams extends Parameters {
  TvKeywordsParams({
    required this.tvId,
  });

  int tvId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/$tvId/keywords',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv latest.
class TvLatestParams extends Parameters {
  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/latest',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv on the air today.
class TvOnAirParams extends Parameters {
  TvOnAirParams({
    this.page = 1,
  });

  int page;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/on_the_air',
          queryParameters: <String, dynamic>{
            'page': page.toString(),
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv popular.
class TvPopularParams extends Parameters {
  TvPopularParams({
    this.page = 1,
  });

  int page;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/popular',
          queryParameters: <String, dynamic>{
            'page': page.toString(),
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv recommendations.
class TvRecommendationsParams extends Parameters {
  TvRecommendationsParams({
    required this.tvId,
  });

  int tvId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/$tvId/recommendations',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv reviews.
class TvReviewsParams extends Parameters {
  TvReviewsParams({
    required this.tvId,
  });

  int tvId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/$tvId/reviews',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv screened theatrically.
class TvScreenedTheatricallyParams extends Parameters {
  TvScreenedTheatricallyParams({
    required this.tvId,
  });

  int tvId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/$tvId/screened_theatrically',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv similar.
class TvSimilarParams extends Parameters {
  TvSimilarParams({
    required this.tvId,
  });

  int tvId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/$tvId/similar',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv top rated.
class TvTopRatedParams extends Parameters {
  TvTopRatedParams({
    this.page = 1,
  });

  int page;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/top_rated',
          queryParameters: <String, dynamic>{
            'page': page.toString(),
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv translations.
class TvTranslationsParams extends Parameters {
  TvTranslationsParams({
    required this.tvId,
  });

  int tvId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/$tvId/translations',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv videos.
class TvVideosParams extends Parameters {
  TvVideosParams({
    required this.tvId,
  });

  int tvId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/tv/$tvId/videos',
        ),
      );
}
